==> webkit2gtk_2.35.1.orig.tar.xz: webkitgtk-2.35.1/Source/WebCore/Modules/WebGPU/GPURenderPassColorAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUColorDict.h"
#include "GPULoadOp.h"
#include "GPUStoreOp.h"
#include "GPUTextureView.h"
#include <pal/graphics/WebGPU/WebGPURenderPassColorAttachment.h>
#include <variant>
#include <wtf/RefPtr.h>
#include <wtf/Vector.h>

namespace WebCore {

struct GPURenderPassColorAttachment {
    PAL::WebGPU::RenderPassColorAttachment convertToBacking() const
    {
        ASSERT(view);
        return {
            view->backing(),
            resolveTarget ? &resolveTarget->backing() : nullptr,
            WTF::switchOn(loadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (const Vector<double>& vector) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return vector;
            }, [&] (const GPUColorDict& color) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return color.convertToBacking();
            }),
            WebCore::convertToBacking(storeOp),
        };
    }

    GPUTextureView* view;
    GPUTextureView* resolveTarget;

    std::variant<GPULoadOp, Vector<double>, GPUColorDict> loadValue;
    GPUStoreOp storeOp;
};

}

==> webkit2gtk_2.35.2.orig.tar.xz: webkitgtk-2.35.2/Source/WebCore/Modules/WebGPU/GPURenderPassColorAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUColorDict.h"
#include "GPULoadOp.h"
#include "GPUStoreOp.h"
#include "GPUTextureView.h"
#include <pal/graphics/WebGPU/WebGPURenderPassColorAttachment.h>
#include <variant>
#include <wtf/RefPtr.h>
#include <wtf/Vector.h>

namespace WebCore {

struct GPURenderPassColorAttachment {
    PAL::WebGPU::RenderPassColorAttachment convertToBacking() const
    {
        ASSERT(view);
        return {
            view->backing(),
            resolveTarget ? &resolveTarget->backing() : nullptr,
            WTF::switchOn(loadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (const Vector<double>& vector) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return vector;
            }, [&] (const GPUColorDict& color) -> std::variant<PAL::WebGPU::LoadOp, Vector<double>, PAL::WebGPU::ColorDict> {
                return color.convertToBacking();
            }),
            WebCore::convertToBacking(storeOp),
        };
    }

    GPUTextureView* view { nullptr };
    GPUTextureView* resolveTarget { nullptr };

    std::variant<GPULoadOp, Vector<double>, GPUColorDict> loadValue;
    GPUStoreOp storeOp { GPUStoreOp::Store };
};

}
